@@ -22,9 +22,10 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-__version__ = "0.4.8"
+__version__ = "0.4.13"
 
 import sys
+
 if sys.version_info < (3, 7):
     print(f'qff {__version__} require Python 3.7+ and 64 bit OS')
     sys.exit(1)
@@ -52,10 +53,10 @@ from qff.tools.utils import (
 )
 
 from qff.tools.config import (
-    DATABASE,
     get_config,
     set_config
 )
+from qff.tools.mongo import DATABASE
 
 from qff.price.query import (
     get_price,
@@ -88,16 +89,12 @@ from qff.price.fetch import (
     fetch_price,
     fetch_today_min_curve,
     fetch_current_ticks,
-    fetch_stock_info,
     fetch_today_transaction,
-    fetch_stock_list,
     fetch_ticks,
-    fetch_stock_block,
-    fetch_stock_xdxr
 )
 from qff.frame.context import (
-    context,
     strategy,
+    context,
     g,
     Context,
     Portfolio,
@@ -115,19 +112,15 @@ from qff.frame.order import (
     order_cancel
 )
 
-from qff.frame.interface import (
-    set_run_freq,
-    set_backtest_period,
-    set_init_cash,
+from qff.frame.api import (
     set_benchmark,
     set_slippage,
     set_order_cost,
+    run_daily,
+    run_file,
     set_universe,
     del_universe,
-    run_daily,
-    pass_today,
-    set_strategy_name,
-    load_strategy_file
+    pass_today
 )
 
 from qff.helper.formula import (
@@ -166,12 +159,8 @@ from qff.helper.formula import (
 )
 
 from qff.helper.indicator import ind_ma, ind_macd, ind_atr, ind_kdj, ind_rsi, ind_boll
-from qff.helper.common import filter_st_stock, filter_paused_stock, filter_20pct_stock, fit_linear, select_zt_stock
+from qff.helper.common import filter_st_stock, filter_paused_stock, filter_20pct_stock, select_zt_stock
 from qff.price.cache import get_current_data, CacheData
 from qff.frame.risk import Risk
-from qff.frame.performance import Performance
-from qff.frame.backtest import back_test_run
-from qff.frame.simtrade import sim_trade_run
+from qff.frame.perf import Perf
 from qff.frame.evaluation import strategy_eval
-
-
