@@ -27,37 +27,24 @@
 
 import threading
 import os
-import sys
 
-from qff.frame.interface import set_run_freq, set_init_cash, set_backtest_period, load_strategy_file
 from qff.frame.settle import settle_by_day, profit_analyse
 from qff.frame.order import order_broker
 from qff.frame.context import context, strategy, RUNSTATUS, RUNTYPE, run_strategy_funcs
 from qff.frame.backup import save_context
-from qff.frame.cli import CLI
+from qff.frame.trace import Trace
 from qff.tools.date import get_trade_days, get_trade_min_list, get_pre_trade_day
 from qff.price.query import get_price
 from qff.tools.logs import log
+from qff.tools.local import cache_path
 
 
-def back_test_run(strategy_file, resume=False):
+def back_test_run(resume=False):
     """
     回测框架运行函数,执行该函数将运行回测过程
-    Parameters
-    ----------
-    strategy_file:策略文件,策略文件中至少包含initialize()函数
-    resume:是否为恢复以前中断的策略，默认全新开始,该参数在__main__.py文件中使用
-
-    Returns
-    -------
-    无返回值
-
-    Examples
-    --------
-    一般在策略文件的尾部使用以下语句，已启动策略的回测。
-
-    if __name__ == '__main__':
-        back_test_run(__file__)
+    :param resume: 是否为恢复以前中断的策略，默认全新开始
+    :type resume: bool
+    :return 无返回值
 
     """
 
@@ -69,25 +56,12 @@ def back_test_run(strategy_file, resume=False):
     else:
         context.status = RUNSTATUS.RUNNING
 
-    # module = sys.argv[0] if strategy_file is None else strategy_file
-    if not load_strategy_file(strategy_file):
-        log.error("策略文件载入失败或缺少初始化函数initialize！***")
-        return
-
     if resume:
         if strategy.process_initialize is not None:
             strategy.process_initialize()
     else:
         strategy.initialize()
 
-    if context.strategy_name is None:
-        context.strategy_name = os.path.basename(sys.argv[0]).split('.')[0]
-    if context.run_freq is None:
-        set_run_freq()
-    if context.start_date is None or context.end_date is None:
-        set_backtest_period()
-    if context.portfolio is None:
-        set_init_cash()
     if context.run_freq == 'tick':
         log.error("回测模式不支持tick运行频率!")
         return
@@ -97,18 +71,20 @@ def back_test_run(strategy_file, resume=False):
                                 end=context.end_date,
                                 market='index')
     context.bm_start = context.bm_data.iloc[0].close
-    sim_thread = threading.Thread(target=_back_test_run)
-    sim_thread.setDaemon(True)
+
+    bt_thread = threading.Thread(target=_back_test_run)
+    bt_thread.setDaemon(True)
     # 运行命令行环境...
-    cli = CLI()
-    sim_thread.start()
-    cli.cmdloop()
+    trace = Trace()
+    bt_thread.start()
+    trace.cmdloop()
     log.warning("命令行交互环境退出...")
-    sim_thread.join()
+    bt_thread.join()
     log.warning("回测框架运行结束！")
 
 
 def _back_test_run():
+
     days = get_trade_days(context.current_dt[0:10], context.end_date)  # 回测中断恢复时可继续运行
     for day in days:
         if context.status != RUNSTATUS.RUNNING:
@@ -164,8 +140,17 @@ def _back_test_run():
         log.info("")
 
     if context.status == RUNSTATUS.PAUSED:
-        log.warning("_back_test_run回测运行暂停，保存过程数据...!")
-        save_context()
+        # log.warning("_back_test_run回测运行暂停，保存过程数据...!")
+
+        default_name = context.strategy_name+'_bt.pkl'
+        if ' ' in default_name:
+            default_name = '_'.join(default_name.split(' '))
+        bf_input = input(f"输入备份文件名称[{default_name}]:")
+        if bf_input == '':
+            bf_input = default_name
+        backup_file = '{}{}{}'.format(cache_path, os.sep, bf_input)
+        print(f"策略备份文件：{backup_file}")
+        save_context(backup_file)
     elif context.status == RUNSTATUS.CANCELED:
         log.warning("_back_test_run回测执行取消...!")
     else:
