@@ -54,7 +54,7 @@ from qff.tools.logs import log
 from qff.tools.word import WordWriter
 from qff.price.query import get_stock_list, get_price
 from qff.price.report import get_valuation
-from qff.tools.date import get_pre_trade_day, get_trade_days, get_trade_gap
+from qff.tools.date import get_trade_days, get_trade_gap
 from qff.tools.local import temp_path, evaluation_path
 
 market = [['震荡', '2002-01-01', '2005-12-31'],
