@@ -48,7 +48,7 @@ import json
 from functools import partial
 
 from qff.frame.context import context, g, RUNTYPE
-from qff.frame.interface import run_daily
+from qff.frame.api import run_daily
 from qff.frame.order import order_value, order_target, ORDER_DEAL
 from qff.price.cache import get_current_data
 from qff.price.query import get_price
@@ -155,7 +155,7 @@ def open_position(security, amount=None, price=None, stop_loss_price=None):
     """
     # 1、根据总仓位控制策略计算当前可用仓位
     if g.ts_context.available_positions < 2000:
-        log.warning('open_position：当前可用仓位金额不足'.format(security))
+        log.debug('open_position：当前可用仓位金额不足'.format(security))
         return None
 
     # 2、根据止损策略计算止损价格
@@ -202,6 +202,14 @@ def get_stop_loss_price(security, price=None):
         return None
 
 
+def can_open_position():
+    """
+    根据仓位控制策略，以及当前仓位情况，判断当前能否进行开仓操作
+    :return: bool True-可以 False-不可以
+    """
+    return g.ts_context.available_positions >= 2000
+
+
 #######################################################################################################################
 # 总仓位控制策略
 def tpc_by_macd(ref_index='000001'):
