@@ -30,7 +30,7 @@ import pandas as pd
 from typing import Dict
 from datetime import datetime
 from bson.regex import Regex
-from qff.tools.config import DATABASE
+from qff.tools.mongo import DATABASE
 from qff.tools.date import util_time_stamp, get_pre_trade_day, is_trade_day, get_real_trade_date, util_date_valid
 from qff.tools.utils import util_code_tolist
 from qff.tools.logs import log
@@ -91,17 +91,18 @@ def get_price(security, start=None, end=None, freq='daily', fields=None, skip_pa
 
     :rtype: DataFrame or None
 
+    :example:
 
-    示例::
+    ::
 
-            # 获取一支股票
-            df = get_price('000001') # 获取股票000001当天的日数据
-            df = get_price('000001', start='2020-01-01', end='2020-01-31 23:00:00', frequency='1m', fields=['open', 'close']) # 获得000001的2020年01月的分钟数据, 只获取open+close字段
-            df = get_price('000001', count = 2, end='2015-01-31', freq='daily', fields=['open', 'close']) # 获取获得000001在2020年01月31日前2个交易日的数据
-            df = get_price('000001', start='2020-12-01 14:00:00', end_date='2020-12-02 12:00:00', freq='1m') # 获得000001的2020年12月1号14:00-2020年12月2日12:00的分钟数据
+        # 获取一支股票
+        df = get_price('000001') # 获取股票000001当天的日数据
+        df = get_price('000001', start='2020-01-01', end='2020-01-31 23:00:00', frequency='1m', fields=['open', 'close']) # 获得000001的2020年01月的分钟数据, 只获取open+close字段
+        df = get_price('000001', count = 2, end='2015-01-31', freq='daily', fields=['open', 'close']) # 获取获得000001在2020年01月31日前2个交易日的数据
+        df = get_price('000001', start='2020-12-01 14:00:00', end_date='2020-12-02 12:00:00', freq='1m') # 获得000001的2020年12月1号14:00-2020年12月2日12:00的分钟数据
 
-            # 获取多只股票
-            panel =  get_price(get_index_stocks('000903')) # 获取中证100的所有成分股的当天日数据, 返回一个[pandas.DataFrame]
+        # 获取多只股票
+        panel =  get_price(get_index_stocks('000903')) # 获取中证100的所有成分股的当天日数据, 返回一个[pandas.DataFrame]
 
 
 
@@ -112,7 +113,7 @@ def get_price(security, start=None, end=None, freq='daily', fields=None, skip_pa
             freq not in ['daily', '1d', 'day', '1min', '5min', '15min', '30min', '60min', '1m', '5m', '15m', '30m',
                          '60m'] or fq not in ['pre', None]:
         log.error('get_price：参数错误！对照API文档检查market、freq、fq等参数的合法性！')
-    if market != 'stock' and (freq == 'pre' or skip_paused):
+    if market != 'stock' and skip_paused:
         log.error('get_price：参数错误！对照API文档检查market、skip_paused、fq等参数的合法性！')
 
     # 2、开始和结束时间计算
@@ -124,7 +125,7 @@ def get_price(security, start=None, end=None, freq='daily', fields=None, skip_pa
         if count is None:
             start = end
         else:
-            start = get_pre_trade_day(end, count - 1)
+            start = get_pre_trade_day(end, count - 1, freq)
 
     if freq in ['daily', '1d', 'day']:
         start = str(start)[:10]
@@ -145,7 +146,7 @@ def get_price(security, start=None, end=None, freq='daily', fields=None, skip_pa
         date_index = 'datetime'
     # 3、其他参数初始化
     code = util_code_tolist(security)
-    coll = DATABASE.get_collection(market + '_' + freq)
+    coll = DATABASE.get_collection(market + '_' + freq[-3:])
     field_list = ['open', 'close', 'low', 'high', 'vol', 'amount']
     if market == 'index':
         field_list += ['up_count', 'down_count']
@@ -215,8 +216,8 @@ def get_price(security, start=None, end=None, freq='daily', fields=None, skip_pa
                     '$in': code
                 },
                 "date": {
-                    "$lte": end,
-                    "$gte": start
+                    "$lte": end[:10],
+                    "$gte": start[:10]
                 }
             },
             {"_id": 0},
@@ -235,7 +236,7 @@ def get_price(security, start=None, end=None, freq='daily', fields=None, skip_pa
             data.reset_index(inplace=True)
             data.drop('adj', axis=1, inplace=True)
             if date_index == 'datetime':
-                data.drop('date', inplace=True)
+                data.drop('date', axis=1, inplace=True)
         else:
             log.error("get_price获取复权因子失败！返回未复权值")
 
@@ -325,7 +326,14 @@ def attribute_history(security, count, unit='1d', fields=None, fq='pre'):
 
     :param fq: 复权选项: pre-前复权 None-不复权 post-后复权
 
-    :return: [pandas.DataFrame]对象, 行索引是datetime字符串, 列索引是属性名字.
+    :return: 返回[pandas.DataFrame]对象，行索引是datetime字符串, 列索引是属性名字.
+
+
+    :type security: str or list
+    :type count: int
+    :type unit: str
+    :type fields: str or list
+    :type fq: str or None
 
     """
     log.debug('调用attribute_history' + str(locals()).replace('{', '(').replace('}', ')'))
@@ -349,25 +357,33 @@ def attribute_history(security, count, unit='1d', fields=None, fq='pre'):
 def get_all_securities(date=None, market='stock', df=False):
     """
     获取平台支持的所有股票信息
-    :param date:日期, 用于获取某日期还在上市的股票信息. 默认值为 None, 表示获取当日的股票信息.
-        特定参数“all”， 表示获取所有日期的上市股票信息。
-        特定参数“delist", 表示获取所有退市股票信息
-        ** 建议使用时添加上指定date **
-    :type date: 字符串
-    :param market: 用来过滤securities的类型,目前支持的type仅有['stock', 'index', 'etf]
-    :type market: 字符串
-    :param df: 返回格式，若是True, 返回[pandas.DataFrame], 否则返回一个仅包含标的代码的list, 默认是False.
-    :type df: 布尔值
 
-    :rtype [pandas.DataFrame] 或者 list, 根据参数df的设置
-    :return:  返回标的列表， 比如：
+    :param date: 查询日期, 用于获取某日期还在上市的股票信息. 默认值为 None, 表示获取当日的股票信息.
+
+        1. 特定参数“all”， 表示获取所有日期的上市股票信息。
+        2. 特定参数“delist", 表示获取所有退市股票信息
+        3. **建议使用时添加上指定date**
+    :param market: 用来过滤securities的类型,目前支持的type仅有['stock', 'index', 'etf]
+    :param df: 返回格式，若是True, 返回[pandas.DataFrame], 否则返回一个仅包含标的代码的list, 默认是False.
+
+    :type date: str
+    :type market: str
+    :type df: bool
+
+    :return:  [pandas.DataFrame or list]返回标的列表
+
+    :example:
+
+    ::
+
         get_all_securities()[:2]
-    返回：
+
+        返回：
         ['000001', '000002']
         当日市场交易的所有股票列表
 
         get_all_securities(df=True)[:2]
-    返回:
+        返回:
         --- 	name	start	     end	    type
         000001	平安银行	1991-04-03	2200-01-01	stock
         000002	万 科Ａ	1991-01-29	2200-01-01	stock
@@ -417,6 +433,7 @@ def get_all_securities(date=None, market='stock', df=False):
 def get_security_info(code, market='stock'):
     """
     获取股票的信息.
+
     :param code: 证券代码
     :type code: 字符串
     :param market: 用来过滤code的类型,目前支持的type仅有['stock', 'index', 'etf]
@@ -487,9 +504,8 @@ def get_stock_name(code=None, date=None):
     """
     获取股票名称
 
-    :param code : 股票代码，支持list, 如果为空，则返回所有股票
-
-    :param date : 查询日期，如果为空，则取上一个交易日日期
+    :param code: 股票代码，支持list, 如果为空，则返回所有股票
+    :param date: 查询日期，如果为空，则取上一个交易日日期
 
     :return dict: 返回股票代码与股票名称的字典
 
@@ -521,7 +537,7 @@ def get_index_name(code=None):
     """
     获取指数名称
 
-    :param code : 指数代码，支持list, 如果为空，则返回所有指数
+    :param code: 指数代码，支持list, 如果为空，则返回所有指数
 
     :return dict: 返回股票代码与股票名称的字典
 
@@ -547,9 +563,8 @@ def get_st_stock(code=None, date=None):
     """
     获取ST股票代码和名称
 
-    :param code : 股票代码，支持list, 如果为空，则查询所有股票
-
-    :param date : 查询日期，如果为空，则取最近交易日日期
+    :param code: 股票代码，支持list, 如果为空，则查询所有股票
+    :param date: 查询日期，如果为空，则取最近交易日日期
 
     :return dict: 返回股票代码与股票名称的字典
 
@@ -583,9 +598,8 @@ def get_paused_stock(code=None, date=None):
     """
     获取停牌的股票代码
 
-    :param code : 股票代码，支持list, 如果为空，则查询所有股票
-
-    :param date : 查询日期，如果为空，则取最近交易日日期
+    :param code: 股票代码，支持list, 如果为空，则查询所有股票
+    :param date: 查询日期，如果为空，则取最近交易日日期
 
     :return list: 返回股票代码列表
 
@@ -620,55 +634,65 @@ def get_paused_stock(code=None, date=None):
 
 
 def get_block_stock(block):
-    """ 根据block名称检索对应的股票代码 """
-
     """
-    blockname = 
-    [
-        300ESG,300周期,300非周,3D打印,5G概念,BIPV概念,C2M概念,CIPS概念,CXO概念,ETC概念
-        HJT电池,IP变现,MCU芯片,MSCIA50,MSCI中盘,MSCI成份,MiniLED,NFT概念,NMN概念,OLED概念
-        PPP模式,PVDF概念,QFII新进,QFII重仓,RCS概念,ST板块,一带一路,三代半导,上海自贸,上证180
-        上证380,上证50,上证中盘,上证创新,上证治理,上证混改,上证红利,上证超大,不活跃股,专精特新
-        业绩预升,业绩预增,业绩预降,东数西算,两年新股,个人持股,中俄贸易,中创100,中华A80,中字头
-        中小100,中小300,中小银行,中盘价值,中盘成长,中证100,中证200,中证央企,中证红利,中证龙头
-        久不分红,乡村振兴,亏损股,云游戏,云科技,云计算,互联金融,人工智能,人脑工程,人造肉
-        代糖概念,仿制药,低价股,低市净率,低市盈率,体育概念,保险新进,保险重仓,信创,信息安全
-        信托重仓,债转股,储能,元宇宙,充电桩,光伏,光刻机,免疫治疗,免税概念,养老概念
-        养老金,内地低碳,军民融合,农业50,农村金融,冷链物流,分拆上市,分散染料,创业300,创业创新
-        创业大盘,创业板50,创业板指,创业蓝筹,创医药,创成长,创投概念,创新100,创科技,创质量
-        券商重仓,券商金股,化肥,北上重仓,北交所,北京冬奥,区块链,区块链50,医废处理,医美概念
-        半导体50,博彩概念,卫星导航,即将解禁,参股新股,参股金融,双创50,发可转债,口罩防护,可燃冰
-        台资背景,含B股,含GDR,含H股,含可转债,员工持股,商誉减值,回购计划,固态电池,国产软件
-        国信价值,国开持股,国证价值,国证农业,国证基建,国证大宗,国证成长,国证服务,国证治理,国证红利
-        国证芯片,国资云,国防军工,土地流转,在线消费,地下管网,地摊经济,地热能,垃圾分类,培育钻石
-        基因概念,基金减仓,基金增仓,基金独门,基金重仓,壳资源,外资背景,大数据,大盘价值,大盘成长
-        大盘股,大飞机,天然气,央企100,央企改革,央视50,婴童概念,字节跳动,安防服务,定增股
-        定增预案,家庭医生,密集调研,富时A50,小盘价值,小盘成长,小米概念,工业互联,工业大麻,工业母机
-        工业气体,已高送转,幽门菌,微利股,微盘股,恒大概念,成渝特区,户数减少,户数增加,扣非亏损
-        投资时钟,抗癌,拟减持,拟增持,持续增长,换电概念,摘帽,操作系统,数字孪生,数字货币
-        数据中心,整体上市,新冠检测,新冠药,新型烟草,新材料,新硬件,新能源车,新进成份,新零售
-        无人机,无人驾驶,无线耳机,昨成交20,昨收活跃,昨日上榜,昨日振荡,昨日涨停,昨日跌停,昨日较弱
-        昨日较强,昨日连板,昨日首板,昨曾涨停,昨曾跌停,昨高换手,智慧城市,智慧政务,智能交通,智能医疗
-        智能家居,智能机器,智能电网,智能电视,智能穿戴,最近复牌,最近多板,最近异动,最近闪拉,最近闪跌
-        有机硅,机构吸筹,板块趋势,核污防治,核电核能,次新开板,次新股,次新超跌,次新预增,武汉规划
-        民企100,民营医院,民营银行,氟概念,氢能源,氮化镓,水产品,水利建设,污水处理,汽车拆解
-        汽车电子,汽车芯片,沪深300,油气改革,泛珠三角,活跃股,海南自贸,海外业务,海峡西岸,消费100
-        消费电子,涉矿概念,深次新股,深注册制,深证100,深证300,深证价值,深证创新,深证成指,深证成长
-        深证治理,深证红利,烟草概念,燃料电池,物业管理,物联网,特斯拉,特高压,猪肉,环保50
-        环渤海,生物疫苗,生物质能,电商概念,电子纸,电子身份,电解液,白酒概念,百元股,百度概念
-        皖江区域,盐湖提锂,知识产权,石墨烯,破净资产,破发行价,碳中和,碳纤维,磷概念,社保新进
-        社保重仓,种业,科创50,科创信息,科技100,租购同权,稀土永磁,稀缺资源,空气治理,粤港澳
-        精选指数,绩优股,维生素,绿色建筑,绿色照明,绿色电力,网红经济,网络游戏,职业教育,聚氨酯
-        股东减持,股东增持,股权分散,股权激励,股权转让,股权集中,胎压监测,能源互联,腾讯概念,腾讯济安
-        航运概念,节能,芯片,苹果概念,草甘膦,虚拟现实,虫害防治,融资增加,融资融券,行业龙头
-        被举牌,装配建筑,装饰园林,要约收购,证金汇金,资源优势,赛马概念,超导概念,超清视频,超级电容
-        跨境电商,轮动趋势,辅助生殖,边缘计算,近已解禁,近期弱势,近期强势,近期新低,近期新高,远程办公
-        连续亏损,送转潜力,送转超跌,透明工厂,通达信88,配股股,配股预案,重组股,重组预案,量子科技
-        金融科技,钛金属,钠电池,钴金属,铁路基建,银河99,锂电池,锂矿,镍金属,长三角
-        长株潭,阿里概念,陆股通减,陆股通增,降解塑料,雄安新区,页岩气,预制菜,预计扭亏,预计转亏
-        预高送转,风沙治理,风能,风险提示,食品安全,高商誉,高市净率,高市盈率,高校背景,高端装备
-        "高股息股","高融资盘","高贝塔值","高负债率","高质押股","鸡肉","鸿蒙概念","黄金概念"
-    ]
+    根据板块名称检索对应的股票代码
+
+    :param block:  板块名称
+
+    :return: 板块对应的股票代码列表
+
+    :type block: str
+
+    :rtype: list
+
+    板块名称汇总::
+
+        blockname =
+        [
+            300ESG,300周期,300非周,3D打印,5G概念,BIPV概念,C2M概念,CIPS概念,CXO概念,ETC概念
+            HJT电池,IP变现,MCU芯片,MSCIA50,MSCI中盘,MSCI成份,MiniLED,NFT概念,NMN概念,OLED概念
+            PPP模式,PVDF概念,QFII新进,QFII重仓,RCS概念,ST板块,一带一路,三代半导,上海自贸,上证180
+            上证380,上证50,上证中盘,上证创新,上证治理,上证混改,上证红利,上证超大,不活跃股,专精特新
+            业绩预升,业绩预增,业绩预降,东数西算,两年新股,个人持股,中俄贸易,中创100,中华A80,中字头
+            中小100,中小300,中小银行,中盘价值,中盘成长,中证100,中证200,中证央企,中证红利,中证龙头
+            久不分红,乡村振兴,亏损股,云游戏,云科技,云计算,互联金融,人工智能,人脑工程,人造肉
+            代糖概念,仿制药,低价股,低市净率,低市盈率,体育概念,保险新进,保险重仓,信创,信息安全
+            信托重仓,债转股,储能,元宇宙,充电桩,光伏,光刻机,免疫治疗,免税概念,养老概念
+            养老金,内地低碳,军民融合,农业50,农村金融,冷链物流,分拆上市,分散染料,创业300,创业创新
+            创业大盘,创业板50,创业板指,创业蓝筹,创医药,创成长,创投概念,创新100,创科技,创质量
+            券商重仓,券商金股,化肥,北上重仓,北交所,北京冬奥,区块链,区块链50,医废处理,医美概念
+            半导体50,博彩概念,卫星导航,即将解禁,参股新股,参股金融,双创50,发可转债,口罩防护,可燃冰
+            台资背景,含B股,含GDR,含H股,含可转债,员工持股,商誉减值,回购计划,固态电池,国产软件
+            国信价值,国开持股,国证价值,国证农业,国证基建,国证大宗,国证成长,国证服务,国证治理,国证红利
+            国证芯片,国资云,国防军工,土地流转,在线消费,地下管网,地摊经济,地热能,垃圾分类,培育钻石
+            基因概念,基金减仓,基金增仓,基金独门,基金重仓,壳资源,外资背景,大数据,大盘价值,大盘成长
+            大盘股,大飞机,天然气,央企100,央企改革,央视50,婴童概念,字节跳动,安防服务,定增股
+            定增预案,家庭医生,密集调研,富时A50,小盘价值,小盘成长,小米概念,工业互联,工业大麻,工业母机
+            工业气体,已高送转,幽门菌,微利股,微盘股,恒大概念,成渝特区,户数减少,户数增加,扣非亏损
+            投资时钟,抗癌,拟减持,拟增持,持续增长,换电概念,摘帽,操作系统,数字孪生,数字货币
+            数据中心,整体上市,新冠检测,新冠药,新型烟草,新材料,新硬件,新能源车,新进成份,新零售
+            无人机,无人驾驶,无线耳机,昨成交20,昨收活跃,昨日上榜,昨日振荡,昨日涨停,昨日跌停,昨日较弱
+            昨日较强,昨日连板,昨日首板,昨曾涨停,昨曾跌停,昨高换手,智慧城市,智慧政务,智能交通,智能医疗
+            智能家居,智能机器,智能电网,智能电视,智能穿戴,最近复牌,最近多板,最近异动,最近闪拉,最近闪跌
+            有机硅,机构吸筹,板块趋势,核污防治,核电核能,次新开板,次新股,次新超跌,次新预增,武汉规划
+            民企100,民营医院,民营银行,氟概念,氢能源,氮化镓,水产品,水利建设,污水处理,汽车拆解
+            汽车电子,汽车芯片,沪深300,油气改革,泛珠三角,活跃股,海南自贸,海外业务,海峡西岸,消费100
+            消费电子,涉矿概念,深次新股,深注册制,深证100,深证300,深证价值,深证创新,深证成指,深证成长
+            深证治理,深证红利,烟草概念,燃料电池,物业管理,物联网,特斯拉,特高压,猪肉,环保50
+            环渤海,生物疫苗,生物质能,电商概念,电子纸,电子身份,电解液,白酒概念,百元股,百度概念
+            皖江区域,盐湖提锂,知识产权,石墨烯,破净资产,破发行价,碳中和,碳纤维,磷概念,社保新进
+            社保重仓,种业,科创50,科创信息,科技100,租购同权,稀土永磁,稀缺资源,空气治理,粤港澳
+            精选指数,绩优股,维生素,绿色建筑,绿色照明,绿色电力,网红经济,网络游戏,职业教育,聚氨酯
+            股东减持,股东增持,股权分散,股权激励,股权转让,股权集中,胎压监测,能源互联,腾讯概念,腾讯济安
+            航运概念,节能,芯片,苹果概念,草甘膦,虚拟现实,虫害防治,融资增加,融资融券,行业龙头
+            被举牌,装配建筑,装饰园林,要约收购,证金汇金,资源优势,赛马概念,超导概念,超清视频,超级电容
+            跨境电商,轮动趋势,辅助生殖,边缘计算,近已解禁,近期弱势,近期强势,近期新低,近期新高,远程办公
+            连续亏损,送转潜力,送转超跌,透明工厂,通达信88,配股股,配股预案,重组股,重组预案,量子科技
+            金融科技,钛金属,钠电池,钴金属,铁路基建,银河99,锂电池,锂矿,镍金属,长三角
+            长株潭,阿里概念,陆股通减,陆股通增,降解塑料,雄安新区,页岩气,预制菜,预计扭亏,预计转亏
+            预高送转,风沙治理,风能,风险提示,食品安全,高商誉,高市净率,高市盈率,高校背景,高端装备
+            "高股息股","高融资盘","高贝塔值","高负债率","高质押股","鸡肉","鸿蒙概念","黄金概念"
+        ]
     """
     collections = DATABASE.stock_block
     cursor = collections.find(
@@ -702,18 +726,18 @@ def get_mtss(security_list, start_date, end_date, fields=None):
 
     :param fields: 字段名或者 list, 可选. 默认为 None, 表示取全部字段, 各字段含义如下：
 
-    ==================  ====================
-    段名	                含义
-    ==================  ====================
-    date	            日期
-    sec_code	        股票代码
-    fin_value	        融资余额(元）
-    fin_buy_value     	融资买入额（元）
-    fin_refund_value	融资偿还额（元）
-    sec_value	        融券余量（股）
-    sec_sell_value	    融券卖出量（股）
-    sec_refund_value	融券偿还股（股）
-    ==================  ====================
+        ==================  ====================
+        字段名	                含义
+        ==================  ====================
+        date	            日期
+        sec_code	        股票代码
+        fin_value	        融资余额(元）
+        fin_buy_value     	融资买入额（元）
+        fin_refund_value	融资偿还额（元）
+        sec_value	        融券余量（股）
+        sec_sell_value	    融券卖出量（股）
+        sec_refund_value	融券偿还股（股）
+        ==================  ====================
 
     :return: 返回一个 pandas.DataFrame 对象，默认的列索引为取得的全部字段. 如果给定了 fields 参数,
      则列索引与给定的 fields 对应.
