@@ -30,7 +30,7 @@ import pandas as pd
 import datetime
 from typing import Dict
 from dateutil.relativedelta import relativedelta
-from qff.tools.config import DATABASE
+from qff.tools.mongo import DATABASE
 from qff.tools.date import (
     util_date_valid,
     get_pre_trade_day,
